@@ -1,3 +1,4 @@
+from functools import partial
 from subprocess import (
     PIPE,
     CalledProcessError,
@@ -5,10 +6,7 @@ from subprocess import (
 )
 
 
-def shell(
-    script,
-    sh = '/bin/bash',
-):
+def shell(script, shell):
     try:
         proc = run(
             script,
@@ -16,7 +14,7 @@ def shell(
             stderr = PIPE,
             check  = True,
             shell  = True,
-            executable = sh,
+            executable = shell,
         )
     except CalledProcessError as exc:
         ret = exc.returncode
@@ -27,3 +25,6 @@ def shell(
         out = proc.stdout.decode('utf-8').strip()
         err = proc.stderr.decode('utf-8').strip()
     return ret, out, err
+
+
+bash = partial(shell, shell='/bin/bash')
