@@ -11,7 +11,7 @@ def callee():
     return caller()
 
 def test_n_caller():
-    assert callee() == 'test_n_caller'
+    assert callee() == 'test_func.test_n_caller'
 
 
 def test_n_todo():
