@@ -14,7 +14,7 @@ def test_n_parser():
                     version = ver.text
                     # print(f'{version = }')
 
-    assert name=='pypbrary'
+    assert name=='pybrary'
     assert version
 
 
