@@ -1,7 +1,9 @@
+from pytest import raises
+
 from pybrary.primes import primes
 
 
-def test_in():
+def test_n_contains():
     assert 0 not in primes
     assert 1 not in primes
     assert 2 in primes
@@ -15,13 +17,22 @@ def test_in():
     assert 11159 in primes
 
 
-def test_gen():
+def test_n_iter():
     expected = 2,3,5,7,11,13,17,19,23
     for e, p in zip(expected, primes):
         assert p == e
 
+def test_n_iindex():
+    assert primes[0] == 2
+    assert primes[1] == 3
+    assert primes[2] == 5
+    assert primes[3] == 7
 
-def test_decomp():
+def test_c_index_error():
+    with  raises(OverflowError):
+        primes[-1]
+
+def test_n_decomp():
     assert primes.factors(12) == [2, 2, 3]
     assert primes.factors(15) == [3, 5]
     assert primes.factors(179) == [179]
